self.__BUILD_MANIFEST={__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":["static/chunks/e82996df-3710848f24a407443b07.js","static/chunks/29107295-2648cb5e919f7c78c7cc.js","static/chunks/857-f5fa3e0a3c7793f3e10e.js","static/chunks/pages/index-02d5e9290b03afe7aa1e.js"],"/_error":["static/chunks/pages/_error-a9f53acb468cbab8a6cb.js"],sortedPages:["/","/_app","/_error"]},self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();